import { LitElement, html, css } from 'lit';
import { customElement } from 'lit/decorators.js';

@customElement('mosaic-rainfall')
export class Rainfall extends LitElement {
  value = 0.0;

  constructor() {
    super();
    this.pullValueFromBackend();
  }

  async pullValueFromBackend() {
    const response = await fetch('RAINFALL_URI');
    const data = await response.json();
    this.setValue(data.total_moisture);

    setTimeout(() => this.pullValueFromBackend(), 1000);
  }

  setValue(newValue: number) {
    this.value = newValue;
    this.requestUpdate();
  }

  static override styles = [
    css`
      .gauge-body {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
        align-content: space-between;
        text-align: center;
      }

      .gauge-label {
        font-weight: bold;
      }
    `
  ]
  override render() {
    return html`
      <div class="gauge-body">
        <div class="gauge-label">Rainfall (inches and mm water)</div>
        <div>${Math.round((this.value / 25.4) * 100)/100} / ${Math.round(this.value*100)/100}</div>
      </div>
`;
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'mosaic-rainfall': Rainfall;
  }
}