import { LitElement, html, css } from 'lit';
import { customElement } from 'lit/decorators.js';

@customElement('mosaic-splork')
export class Splork extends LitElement {
  value = 0.0;

  constructor() {
    super();
    this.pullValueFromBackend();
  }

  async pullValueFromBackend() {
    const response = await fetch('SPLORK_URI');
    const data = await response.json();
    const result = data.message;

    this.setValue(result);
  }

  setValue(newValue: number) {
    this.value = newValue;
    this.requestUpdate();
  }

  static override styles = [
    css`
      .gauge-body {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
        align-content: space-between;
        text-align: center;
      }

      .gauge-label {
        font-weight: bold;
      }
    `
  ]
  override render() {
    return html`
      <div class="gauge-body">
        <div>${this.value}</div>
      </div>
`;
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'mosaic-splork': Splork;
  }
}