import { LitElement, css, html } from 'lit';
import { customElement } from 'lit/decorators.js';
import { format } from 'date-fns-tz';

@customElement('mosaic-time')
export class Time extends LitElement {
  time = '';

  constructor() {
    super();
    this.reloadTime();
  }


  async reloadTime() {
    const date = new Date();
    const hours = date.getUTCHours();
    const minutes = date.getUTCMinutes();
    const seconds = date.getUTCSeconds();
  
    let beats = (hours * 3600 + 60 * minutes + seconds) / 86.4;

    beats = Math.round(beats * 1000) / 1000;

    this.setData(`${format(date, 'yyyy-MM-dd', {timeZone: 'UTC'})}@${beats.toFixed(4)}`);

    setTimeout(() => this.reloadTime(), 10);
  }

  setData(time: string) {
    this.time = time;
    this.requestUpdate();
  }

  static override styles = [
    css`
      .gauge-body {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
        align-content: space-between;
        text-align: center;
      }

      .gauge-label {
        font-weight: bold;
      }
    `
  ]
  override render() {
    return html`
      <div class="gauge-body">
        <div class="gauge-label">Universal Decimal Time</div>
        <div>⧖${this.time}</div>
      </div>
`;
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'mosaic-time': Time;
  }
}