import { LitElement, css, html } from 'lit';
import { customElement } from 'lit/decorators.js';

@customElement('mosaic-weather')
export class Weather extends LitElement {
  temp = 0.0;

  constructor() {
    super();
    this.pullFromBackend();
  }


  async pullFromBackend() {
    const apiUri = `https://api.openweathermap.org/data/2.5/weather?q=Olathe,Kansas,USA&appid=OPENWEATHER_API_KEY&units=metric`;
    const response = await fetch(apiUri);

      const data = await response.json();

      this.setData(data.main.temp);
  }

  setData(temp: number) {
    this.temp = temp;
    this.requestUpdate();
  }

  static override styles = [
    css`
      .gauge-body {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
        align-content: space-between;
        text-align: center;
      }

      .gauge-label {
        font-weight: bold;
      }
    `
  ]
  override render() {
    return html`
      <div class="gauge-body">
        <div class="gauge-label">Temperature in Olathe, Kansas, United States of America</div>
        <div class="gauge-label">Temperature (in C)</div>
        <div>${this.temp}</div>
        <div class="gauge-label">Temperature (in F)</div>
        <div>${Math.round((this.temp*9)/5 + 32)}</div>
      </div>
`;
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'mosaic-weather': Weather;
  }
}